# Changy

Simplest changelog manager, oriented to human editing, not to special message formatting in commits.

Inspired by

- [Changie](https://github.com/miniscruff/changie)
- [Towncrier](https://github.com/twisted/towncrier)

But simpler, oriented to editing text files by hand: without cli commands to input changes, without strict messages format, etc.
